<script setup>
import AuthenticatedLayout from '@/Layouts/AuthenticatedLayout.vue';
import ProductFilter from '@/components/ProductFilter.vue'

import { ref, onMounted, computed } from 'vue';
import { Head, usePage, useForm } from '@inertiajs/vue3';

const page = usePage();
console.log(page.props);
console.log(page.props.auth.user.id);

const favourites = computed(() => page.props.favourites || []);
const products = computed(() => page.props.products || []);
console.log(products);
console.log(favourites);
const isMobile = ref(window.innerWidth <= 768);
const flashMessage = ref('');

const form = useForm({});

const handleResize = () => {
    isMobile.value = window.innerWidth <= 768; // Adjust the threshold as needed
}

onMounted(() => {
    window.addEventListener('resize', handleResize);
    handleResize();
});

const deleteFavourite = (favourite) => {
    const favouriteID = favourite.fav_id;
    console.log(favouriteID);

    form.post(route('favourite.delete',{id: favouriteID}), {
        onSuccess: () => {
            flashMessage.value = "Favourite deleted";
        },
        onError: (error) => {
            console.error(error);
        }
    });
};
</script>

<template>
    <Head title="Favourites" />

    <AuthenticatedLayout>
        <template #header>
            <h2 class="font-semibold text-xl text-gray-800 leading-tight">Favourites</h2>
        </template>

        <div class="py-12 container">
            <div class="row">
                <div v-if="flashMessage" class="col-12 max-w-7xl mx-auto sm:px-6 lg:px-8 font-bold text-red-600">
                    <div class="form-row mb-6">
                        <div class="col-md-6">
                            <h4>{{ flashMessage }}</h4>
                        </div>
                    </div>
                </div>

                <div class="col-12 col-sm-3 max-w-7xl mx-auto sm:px-6 lg:px-8">
                    <div class="bg-white overflow-hidden shadow-sm sm:rounded-lg">
                        <ProductFilter></ProductFilter>
                    </div>
                </div>
                <div class="col-12 col-sm-9 max-w-7xl mx-auto sm:px-6 lg:px-8">
                    <div v-if="loading">Loading...</div>
                    <table v-else-if="favourites && favourites.length" class="table table-striped">
                        <thead>
                            <tr>
                                <th>Item Number</th>
                                <th v-if="!isMobile">Description</th>
                                <th>Price</th>
                                <th>Stock</th>
                                <th>Quantity</th>
                                <th></th>
                                <th></th>
                            </tr>
                        </thead>
                        <tbody>
                            <tr v-for="product in favourites" :key="product.id">
                                <td>{{ product.item_number }}</td>
                                <td v-if="!isMobile" >{{ product.nags_description }}</td>
                                <td>{{ product.price }}</td>
                                <td :class="product.stock == 1 ? 'text-success' : 'text-danger'">{{ product.stock == 1 ? "In Stock" : "Please Call" }}</td>
                                <td class="cart_qty"><input type="text" :name="product.id" id="cart_qty" min="1" /></td>
                                <td><button>Add to cart</button></td>
                                <td><button @click="deleteFavourite(product)">Delete</button></td>
                            </tr>
                        </tbody>
                    </table>
                    <p v-else>No favourites found.</p>
                </div>
            </div>
        </div>
    </AuthenticatedLayout>
</template>
<style scoped>
table tr td {
    max-width: 200px;
}
.cart_qty input {
    width: 70px;
    padding: 0 5px;
    height: 33px;
}
</style>
